@@ -1,7 +1,7 @@
 /*
  * HomePieceOfFurniture3D.java 23 jan. 09
  *
- * Sweet Home 3D, Copyright (c) 2007-2009 Emmanuel PUYBARET / eTeks <info@eteks.com>
+ * Sweet Home 3D, Copyright (c) 2024 Space Mushrooms <info@sweethome3d.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -276,7 +276,7 @@ public class HomePieceOfFurniture3D extends Object3DBranch {
   private void updatePieceOfFurnitureTransform() {
     TransformGroup transformGroup = (TransformGroup)getChild(0);
     Transform3D pieceTransform = ModelManager.getInstance().getPieceOfFurnitureNormalizedModelTransformation(
-        (HomePieceOfFurniture)getUserData(), transformGroup.getChild(0));
+        (HomePieceOfFurniture)getUserData(), ((Group)transformGroup.getChild(0)).getChild(0));
     // Change model transformation
     transformGroup.setTransform(pieceTransform);
   }
