@@ -1,7 +1,7 @@
 /*
  * PhotosPanel.java 5 Nov 2012
  *
- * Sweet Home 3D, Copyright (c) 2012 Emmanuel PUYBARET / eTeks <info@eteks.com>
+ * Sweet Home 3D, Copyright (c) 2024 Space Mushrooms <info@sweethome3d.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ import javax.swing.UIManager;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-import com.eteks.sweethome3d.j3d.PhotoRenderer;
+import com.eteks.sweethome3d.j3d.AbstractPhotoRenderer;
 import com.eteks.sweethome3d.model.Camera;
 import com.eteks.sweethome3d.model.Home;
 import com.eteks.sweethome3d.model.Selectable;
@@ -643,10 +643,11 @@ public class PhotosPanel extends JPanel implements DialogView {
         home.setCamera(camera);
         if (quality >= 2) {
           // Use photo renderer
-          PhotoRenderer photoRenderer = new PhotoRenderer(home, this.object3dFactory,
-            quality == 2
-                ? PhotoRenderer.Quality.LOW
-                : PhotoRenderer.Quality.HIGH);
+          AbstractPhotoRenderer photoRenderer = AbstractPhotoRenderer.createInstance(
+              camera.getRenderer(), home, this.object3dFactory,
+              quality == 2
+                  ? AbstractPhotoRenderer.Quality.LOW
+                  : AbstractPhotoRenderer.Quality.HIGH);
           int bestImageHeight;
           // Update ratio if lens is fisheye or spherical
           if (camera.getLens() == Camera.Lens.FISHEYE) {
