@@ -1,7 +1,7 @@
 /*
  * HomeFurnitureController.java 30 mai 07
  *
- * Sweet Home 3D, Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>
+ * Sweet Home 3D, Copyright (c) 2024 Space Mushrooms <info@sweethome3d.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1971,7 +1971,8 @@ public class HomeFurnitureController implements Controller {
           piece.setProperty(property.getKey(), property.getValue());
         }
       }
-      if (description != null) {
+      if (modifiedFurniture.length == 1
+          || description != null) {
         piece.setDescription(description);
       }
       if (!(piece instanceof HomeFurnitureGroup)) {
