@@ -1,7 +1,7 @@
 /*
  * HomeCameraTest.java 21 juin 2007
  * 
- * Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Copyright (c) 2024 Space Mushrooms <info@sweethome3d.com>
  * 
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -389,7 +389,7 @@ public class HomeCameraTest extends ComponentTestFixture {
         (JSpinner)TestUtilities.getField(observerCameraPanel, "fieldOfViewSpinner");
     JSpinner elevationSpinner = 
         (JSpinner)TestUtilities.getField(observerCameraPanel, "elevationSpinner");
-    assertEquals("Wrong field of view", (int)Math.round(Math.toDegrees(observerCamera.getFieldOfView())), 
+    assertEquals("Wrong field of view", (float)Math.toDegrees(observerCamera.getFieldOfView()), 
         fieldOfViewSpinner.getValue());
     assertEquals("Wrong elevation", (float)Math.round(observerCamera.getZ() * 100) / 100, 
         elevationSpinner.getValue());
